@@ -599,6 +599,8 @@ def files_create( fp , trimpath = "" ) :
     with open( fp , mode = "rb" ) as file : 
         fc = file.read( )
 
+
+    # FIXME TODO use better hash lib blake2b?
     fh = hashlib.md5( fc ).hexdigest( )
 
     ####################################################################
@@ -606,8 +608,7 @@ def files_create( fp , trimpath = "" ) :
     fp_processed = fp
 
     if( trimpath != "" ) :
-        #s_log.write( "trimpath=" + trimpath )
-        fp_processed = fp.lstrip( trimpath )
+        fp_processed = fp[len(trimpath ):]
 
 
     statinfo = os.stat( fp )
@@ -712,11 +713,12 @@ def files_restore( rpath = False ) :
         fp_source = db_file[ "fp" ]
 
         if(rpath!=False):
+            # FIXME TODO WARNING this removes "chars"!
             fp_target=rpath.rstrip("/")+ "/" + fp_source
         else:
             fp_target=fp_source
 
-        s_log.write(fp_source+" -> "+fp_target)
+        #s_log.write(fp_source+" -> "+fp_target)
 
         dp = s_util.path_dirname( fp_target )
         #print(dp)
@@ -735,6 +737,7 @@ def files_createall( pat ) :
     # Let's be clever and try to trim the pattern matching directory...
 
     # FIXME TODO be careful... we are only checking for wildcard "**"
+    # FIXME TODO WARNING this removes "chars"!
     pat_trim = pat.rstrip( "**" )
     if( pat_trim == pat ) :
         pat_trim = ""
