@@ -114,6 +114,39 @@ def check_connectivity( ) :
 
 #####################################################################
 
+def job_rping( jid_in = False ) :
+
+    if( jid_in == False ) :
+        s_log.write( "jid_in??" )
+        return( False )
+
+
+
+    headers =   {
+                    "X-Omni-Action": "job_rping" ,
+                    "X-Omni-Jid": jid_in ,
+                }
+
+
+    res = get_request_response( headers )
+
+    if( res == False ) :
+        s_log.write( "res??" )
+        return( False )
+
+    #s_log.write( str( res.headers ) )
+
+    if( "X-Omni-Data" in res.headers ) :
+        data=s_util.json_loads(res.headers["X-Omni-Data"])
+        return( data)
+
+
+    return( False )
+
+#####################################################################
+
+
+
 def job_request( params = { } ) :
 
     #if( not s_util.ready( ) ) :
@@ -129,6 +162,8 @@ def job_request( params = { } ) :
     #####################################################################
 
     payload = s_db.blob_get( )
+    payload_len=len( payload )
+    if(payload_len>0) : s_log.write( "PAYLOAD REQUEST "+str(payload_len))
 
     #####################################################################
 
@@ -229,6 +264,11 @@ def job_response( jid ) :
         s_log.write( "job_response STATE ERROR [" + jid + "]" )
         return( True )
 
+    if( res.headers[ "X-Omni-State" ].startswith( "cancel" ) ) :
+        # FIXME TODO should add more info here...
+        s_log.write( "job_response CANCEL..LED [" + jid + "]" )
+        return( True )
+
     if( res.headers[ "X-Omni-State" ] != "done" ) :
         s_log.write( "job_response !=Done [" + jid + "]" )
         return( None )
@@ -237,6 +277,8 @@ def job_response( jid ) :
         s_log.write( "ERROR EMPTY RES CONTENT" )
         return( False )
 
+    payload_len=len( res.content )
+    if(payload_len>0) : s_log.write( "PAYLOAD RESPONSE "+str(payload_len))
     s_db.blob_set( res.content )
 
     # FIXME TODO we must have this before AND after the DB SET
@@ -362,8 +404,6 @@ def get_request_response( request_headers = { }  , payload = "" ) :
 
     time.sleep( 0.1 )
 
-    #s_log.write( len( payload ) )
-
     if not "User-Agent" in request_headers :
         request_headers[ "User-Agent" ] = "sapiadapter"
     if not "X-Omni-Authorization" in request_headers :
@@ -453,7 +493,7 @@ def get_request_response( request_headers = { }  , payload = "" ) :
         if( "X-Sapi-Tokensession" in response.headers ) :
             token_session=response.headers["X-Sapi-Tokensession"]
             s_config.set_key_fsoneshot("token_session",token_session)
-            s_log.write(token_session)
+            #s_log.write(token_session)
         return( response )
 
     #####################################################################
@@ -469,7 +509,7 @@ def get_request_response( request_headers = { }  , payload = "" ) :
     if( response.status_code == 418 ) :
         s_log.write( "ERROR 418" )
         s_log.write( "Sleep while tea is brewing" )
-        s_util.sleep( 60 )
+        s_util.sleep( 10 )
 
     time.sleep( 10 )
 
