@@ -263,6 +263,7 @@ def full_stack():
     trc = 'Traceback (most recent call last):\n'
     stackstr = trc + ''.join(traceback.format_list(stack))
     if exc is not None:
+        # FIXME TODO WARNING this removes "chars"!
         stackstr += '  ' + traceback.format_exc().lstrip(trc)
     return stackstr
 
@@ -494,6 +495,10 @@ def time_now_str( ) :
 def datetime_utcnow( ) :
     return( datetime.utcnow( ) )
 
+
+def datetime_timestamp( ) :
+    return( datetime.now( ).timestamp( ) )
+
 def url_parse( u ) :
     return(urllib.parse.urlparse(u))
 
@@ -630,6 +635,12 @@ def file_settimes( fp , t ) :
 def file_replace( fp_source , fp_target ):
     os.replace(fp_source,fp_target)
 
+def file_tmprandom(  ) :
+    fp = "/tmp/sapitmp_" + uhash( ) + ".tmp"
+    data = num_randomlist( 10000 )
+    with open( fp, "w" ) as f :
+        f.write( json_encode( data ) )
+    return( fp )
 
 ################
 
