@@ -14,6 +14,8 @@
 #####################################################################
 
 import importlib
+import multiprocessing
+from multiprocessing import Process
 from . import s_log , s_config , s_net , s_util , s_db , s_cache , s_cleanup 
 
 #####################################################################
@@ -176,7 +178,6 @@ def runner_omnibus( path_runner ) :
     # Required to make module name scope available in function for importlib
     global _sapi_runner_omnibus
 
-
     ###############################################################################
     # _CONTAINER_LOCAL_APPSAPIENABLED
 
@@ -185,13 +186,12 @@ def runner_omnibus( path_runner ) :
     #    s_log.write("_CONTAINER_LOCAL_APPSAPIENABLED NONE DISABLED")
     #    s_util.idle( )
 
-    if( env_appsapienabled.endswith("_APPSAPIENABLED_")) :
+    if( env_appsapienabled and env_appsapienabled.endswith( "_APPSAPIENABLED_" ) ) :
         s_log.write("_CONTAINER_LOCAL_APPSAPIENABLED ENDSWITH DISABLED")
         s_util.idle( )
 
     ###############################################################################
 
-
     s_log.write( "RUNNER_OMNIBUS START " + path_runner )
 
     if( not s_util.sys_path_append_fp( path_runner ) ) :
@@ -234,11 +234,50 @@ def runner_omnibus( path_runner ) :
 
         # FIXME TODO add try catch
 
+        runner_exitcode = -999
+
         try :
-            runner_exitcode = _sapi_runner_omnibus._entrypoint( )
-            if( runner_exitcode > 0 ) :
-                s_log.write( "ERROR _sapi_runner_omnibus runner_exitcode " + str( runner_exitcode ) , consoleprint = True )
-                continue
+           
+            #runner_exitcode = _sapi_runner_omnibus._entrypoint( )
+
+            ########################################################
+
+            # This could change if runner does a sapi request!?!?
+            jid_omnibus = s_config.get_key( "jid" )
+
+            s_log.write( "process start" )
+            prc1 = multiprocessing.Process( target = _sapi_runner_omnibus._entrypoint , daemon = True )
+            prc1.start( )
+            prc_starttime = s_util.uptime( )
+            while prc1.is_alive( ) :
+                
+                ##########
+                job_rping = s_net.job_rping( jid_omnibus )
+                if(job_rping!=False):
+                    if("state" in job_rping and job_rping["state"]=="cancel"):
+                        s_log.write( "cancel job!!!!" )
+                        prc1.kill( )
+                        break
+
+                    s_log.write(job_rping)
+                ##########
+
+                s_util.sleep( 3 )
+                # FIXME TODO should be configurable and use actual time not some counter
+                if ( s_util.uptime( ) - prc_starttime ) > 900 :
+                    s_log.write( "prc_counter!!! KILL" )
+                    prc1.kill( )
+                    
+            prc1.join( )
+            # -9 when kill, 1 when exception/error..? 0 is OK
+            runner_exitcode = prc1.exitcode
+            s_log.write( "process end" )
+
+            ########################################################
+
+            #if( runner_exitcode != 0 ) :
+            #    s_log.write( "ERROR _sapi_runner_omnibus runner_exitcode " + str( runner_exitcode ) , consoleprint = True )
+            #    continue
         except Exception as e :
             #ERROR _sapi_runner_omnibus Exception module 'sapiadapter.sapiadapter' has no attribute 'write'
 
@@ -252,7 +291,7 @@ def runner_omnibus( path_runner ) :
 
         #####################################################
 
-
+        #if runner_exitcode==0:
         s_net.job_set( )
 
         #####################################################
